@@ -35,9 +35,9 @@ setMethod("Math", signature(x="SpatExtent"),
     function(x){ 
 		oper <- as.vector(.Generic)[1]
 		if (oper == "floor") {
-			x@ptr <- x@ptr$floor(x@ptr)
-		} else if (oper == "ceil") {
-			x@ptr <- x@ptr$ceil(x@ptr)
+			x@ptr <- x@ptr$floor()
+		} else if (oper == "ceiling") {
+			x@ptr <- x@ptr$ceil()
 		} else {
 			stop("not implemented for SpatExtent")
 		}
@@ -52,7 +52,7 @@ setMethod("Math2", signature(x="SpatExtent"),
     function(x, digits=0){ 
 		oper <- as.vector(.Generic)[1]
 		if (oper == "round") {
-			x@ptr <- x@ptr$round(x@ptr, digits)
+			x@ptr <- x@ptr$round(digits)
 			if (!x@ptr$valid) {
 				stop("invalid extent")
 			}
