@@ -9,7 +9,7 @@ function(x, subset, filename="", overwrite=FALSE, wopt=list(), ...) {
 	if (is.character(subset)) {
 		i <- stats::na.omit(match(subset, names(x)))
 		if (length(i)==0) {
-			stop("invalid layer names")
+			return (NULL)
 		} else if (length(i) < length(subset)) {
 			warning("invalid layer names omitted")
 		}
