@@ -139,14 +139,23 @@ SpatVector::SpatVector(const SpatVector &x) {
 */
 
 SpatVector::SpatVector(SpatExtent e, std::string crs) {
-	SpatPart p;
-	p.x = { e.xmin, e.xmin, e.xmax, e.xmax, e.xmin };
-	p.y = { e.ymin, e.ymax, e.ymax, e.ymin, e.ymin };
+	std::vector<double> x = { e.xmin, e.xmin, e.xmax, e.xmax, e.xmin };
+	std::vector<double> y = { e.ymin, e.ymax, e.ymax, e.ymin, e.ymin };
+	SpatPart p(x, y);
 	SpatGeom g(p);
+	g.gtype = polygons;
 	setGeom(g);
 	setSRS( {crs});
 }
 
+SpatVector::SpatVector(std::vector<double> x, std::vector<double> y, SpatGeomType g, std::string crs) {
+	SpatPart p(x, y);
+	SpatGeom geom(p);
+	geom.gtype = g;
+	setGeom(geom);
+	setSRS( {crs} );
+}
+
 
 std::vector<double> SpatVector::getDv(unsigned i) {
 	return df.getD(i);
